==> invoice-client-4.1.5-20200228.110036-65-sources.jar: com/xforceplus/seller/invoice/client/model/open/OpenInvoiceRedflushRequest.java <==
package com.xforceplus.seller.invoice.client.model.open;

/**
 * Created by yang on 20/2/5.
 */
public class OpenInvoiceRedflushRequest {
    private String invoiceNo;
    private String invoiceCode;
    private Integer releaseFlag;

    private String redNotification;
    private String 	terminalCode ;

    public String getInvoiceNo() {
        return invoiceNo;
    }

    public void setInvoiceNo(String invoiceNo) {
        this.invoiceNo = invoiceNo;
    }

    public String getInvoiceCode() {
        return invoiceCode;
    }

    public void setInvoiceCode(String invoiceCode) {
        this.invoiceCode = invoiceCode;
    }

    public Integer getReleaseFlag() {
        return releaseFlag;
    }

    public void setReleaseFlag(Integer releaseFlag) {
        this.releaseFlag = releaseFlag;
    }

    public String getRedNotification() {
        return redNotification;
    }

    public void setRedNotification(String redNotification) {
        this.redNotification = redNotification;
    }

    public String getTerminalCode() {
        return terminalCode;
    }

    public void setTerminalCode(String terminalCode) {
        this.terminalCode = terminalCode;
    }

    @Override
    public String toString() {
        return "OpenInvoiceRedflushRequest{" +
                "invoiceNo='" + invoiceNo + '\'' +
                ", invoiceCode='" + invoiceCode + '\'' +
                ", releaseFlag=" + releaseFlag +
                ", redNotification='" + redNotification + '\'' +
                ", terminalCode='" + terminalCode + '\'' +
                '}';
    }
}

==> invoice-client-4.1.6-20200515.055925-40-sources.jar: com/xforceplus/seller/invoice/client/model/open/OpenInvoiceRedflushRequest.java <==
package com.xforceplus.seller.invoice.client.model.open;

/**
 * Created by yang on 20/2/5.
 */
public class OpenInvoiceRedflushRequest {
    private String invoiceNo;
    private String invoiceCode;
    private Integer releaseFlag;

    private String redNotification;
    private String 	terminalCode ;

    //红冲票发票类型
    private String 	redflushinvoiceType ;

    public String getRedflushinvoiceType() {
        return redflushinvoiceType;
    }

    public void setRedflushinvoiceType(String redflushinvoiceType) {
        this.redflushinvoiceType = redflushinvoiceType;
    }

    public String getInvoiceNo() {
        return invoiceNo;
    }

    public void setInvoiceNo(String invoiceNo) {
        this.invoiceNo = invoiceNo;
    }

    public String getInvoiceCode() {
        return invoiceCode;
    }

    public void setInvoiceCode(String invoiceCode) {
        this.invoiceCode = invoiceCode;
    }

    public Integer getReleaseFlag() {
        return releaseFlag;
    }

    public void setReleaseFlag(Integer releaseFlag) {
        this.releaseFlag = releaseFlag;
    }

    public String getRedNotification() {
        return redNotification;
    }

    public void setRedNotification(String redNotification) {
        this.redNotification = redNotification;
    }

    public String getTerminalCode() {
        return terminalCode;
    }

    public void setTerminalCode(String terminalCode) {
        this.terminalCode = terminalCode;
    }

    @Override
    public String toString() {
        return "OpenInvoiceRedflushRequest{" +
                "invoiceNo='" + invoiceNo + '\'' +
                ", invoiceCode='" + invoiceCode + '\'' +
                ", releaseFlag=" + releaseFlag +
                ", redNotification='" + redNotification + '\'' +
                ", terminalCode='" + terminalCode + '\'' +
                ", redflushinvoiceType='" + redflushinvoiceType + '\'' +
                '}';
    }
}
